============
Contributors
============

Creator:

* `Austin Hodges <https://github.com/ahodges9>`_

Developers:

* `Matthew Bowley <https://github.com/not-matt>`_

* `Matt Muller <https://github.com/Mattallmighty>`_

* `Shaun Eccles-Smith <https://github.com/shauneccles>`_

* `Yeon (a.k.a. Blade) <https://github.com/YeonV>`_

* `Chris Reese <https://github.com/THATDONFC>`_

Special thanks to our `community developers! <https://github.com/LedFx/LedFx/graphs/contributors>`_